@@ -31,7 +31,7 @@
 
 #include "ctkconfig.h"
 #include "ctkhelp.h"
-#include "ctkimage.h"
+#include "ctkbanner.h"
 
 
 /* local prototypes */
@@ -203,6 +203,8 @@ GtkWidget *ctk_multisample_new(NvCtrlAttributeHandle *handle,
     GtkWidget *check_button;
     GtkWidget *menu;
     GtkWidget *scale;
+    GtkObject *adjustment;
+    gint min, max;
     
     gint val, app_control, override, enhance, i;
     
@@ -317,9 +319,13 @@ GtkWidget *ctk_multisample_new(NvCtrlAttributeHandle *handle,
 
             /* Antialiasing scale */
 
-            scale = gtk_hscale_new_with_range
-                (0, ctk_multisample->fsaa_translation_table_size - 1, 1);
-            gtk_range_set_value(GTK_RANGE(scale), val);
+            min = 0;
+            max = ctk_multisample->fsaa_translation_table_size - 1;
+
+            /* create the slider */
+            adjustment = gtk_adjustment_new(val, min, max, 1, 1, 0.0);
+            scale = gtk_hscale_new(GTK_ADJUSTMENT(adjustment));
+            gtk_adjustment_set_value(GTK_ADJUSTMENT(adjustment), val);
             
             gtk_scale_set_draw_value(GTK_SCALE(scale), TRUE);
             gtk_scale_set_value_pos(GTK_SCALE(scale), GTK_POS_TOP);
@@ -416,9 +422,13 @@ GtkWidget *ctk_multisample_new(NvCtrlAttributeHandle *handle,
             
             /* Aniso scale */
 
-            scale = gtk_hscale_new_with_range(valid.u.range.min,
-                                              valid.u.range.max, 1);
-            gtk_range_set_value(GTK_RANGE(scale), val);
+            min = valid.u.range.min;
+            max = valid.u.range.max;
+
+            /* create the slider */
+            adjustment = gtk_adjustment_new(val, min, max, 1, 1, 0.0);
+            scale = gtk_hscale_new(GTK_ADJUSTMENT(adjustment));
+            gtk_adjustment_set_value(GTK_ADJUSTMENT(adjustment), val);
 
             gtk_scale_set_draw_value(GTK_SCALE(scale), TRUE);
             gtk_scale_set_value_pos(GTK_SCALE(scale), GTK_POS_TOP);
