@@ -43,6 +43,7 @@
 #include "ctkconfig.h"
 
 #include "ctkscreen.h"
+#include "ctkslimm.h"
 #include "ctkgpu.h"
 #include "ctkcolorcorrection.h"
 #include "ctkxvideo.h"
@@ -114,8 +115,6 @@ static GtkWidget *create_quit_dialog(CtkWindow *ctk_window);
 static void quit_response(GtkWidget *, gint, gpointer);
 static void save_settings_and_exit(CtkWindow *);
 
-static void add_special_config_file_attributes(CtkWindow *ctk_window);
-
 static void add_display_devices(CtkWindow *ctk_window, GtkTreeIter *iter,
                                 NvCtrlAttributeHandle *handle,
                                 CtkEvent *ctk_event,
@@ -374,7 +373,8 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **screen_handles,
                           gint num_gpu_handles,
                           NvCtrlAttributeHandle **vcs_handles,
                           gint num_vcs_handles,
-                          ParsedAttribute *p, ConfigProperties *conf)
+                          ParsedAttribute *p, ConfigProperties *conf,
+                          CtrlHandles *pCtrlHandles)
 {
     GObject *object;
     CtkWindow *ctk_window;
@@ -387,11 +387,15 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **screen_handles,
     GtkWidget *toggle_button;
     GtkWidget *statusbar;
     GtkWidget *eventbox;
+    GtkWidget *label;
+    GtkRequisition req;
+    gint width;
 
     GtkTreeViewColumn *column;
     GtkCellRenderer *renderer;
     GtkTreeSelection *selection;
     GtkTreeModel *model;
+    GtkTreeIter iter;
     GtkTextTagTable *tag_table;
 
     GtkTextBuffer *help;
@@ -412,7 +416,7 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **screen_handles,
     
     /* create the config object */
 
-    ctk_window->ctk_config = CTK_CONFIG(ctk_config_new(conf));
+    ctk_window->ctk_config = CTK_CONFIG(ctk_config_new(conf, pCtrlHandles));
     ctk_config = ctk_window->ctk_config;
     
     /* create the quit dialog */
@@ -590,7 +594,8 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **screen_handles,
                                                         CTK_DISPLAY_CONFIG(child)),
                          ctk_window, NULL, NULL,
                          "X Server Display Configuration",
-                         NULL, NULL, NULL);
+                         NULL, ctk_display_config_selected,
+                         ctk_display_config_unselected);
             }
         }
     }
@@ -600,7 +605,6 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **screen_handles,
 
     for (i = 0; i < num_screen_handles; i++) {
 
-        GtkTreeIter iter;
         gchar *screen_name;
         GtkWidget *child;
         NvCtrlAttributeHandle *screen_handle = screen_handles[i];
@@ -635,6 +639,17 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **screen_handles,
                            CTK_WINDOW_CONFIG_FILE_ATTRIBUTES_FUNC_COLUMN,
                            NULL, -1);
 
+        if (num_vcs_handles) {
+            /* SLI Mosaic Mode information */
+
+            child = ctk_slimm_new(screen_handle, ctk_event, ctk_config);
+            if (child) {
+                help = ctk_slimm_create_help(tag_table, "SLI Mosaic Mode Settings");
+                add_page(child, help, ctk_window, &iter, NULL,
+                         "SLI Mosaic Mode Settings", NULL, NULL, NULL);
+            }
+        }
+
         /* color correction */
 
         child = ctk_color_correction_new(screen_handle, ctk_config,
@@ -746,7 +761,6 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **screen_handles,
 
     for (i = 0; i < num_gpu_handles; i++) {
         
-        GtkTreeIter iter;
         gchar *gpu_product_name;
         gchar *gpu_name;
         GtkWidget *child;
@@ -849,7 +863,6 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **screen_handles,
 
     for (i = 0; i < num_vcs_handles; i++) {
         
-        GtkTreeIter iter;
         gchar *vcs_product_name;
         gchar *vcs_name;
         GtkWidget *child;
@@ -944,12 +957,43 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **screen_handles,
     gtk_tree_view_expand_all(ctk_window->treeview);
     gtk_tree_view_columns_autosize(ctk_window->treeview);
 
+    /* Make sure the first item is selected */
+    if ( gtk_tree_model_get_iter_first(model, &iter) ) {
+        gtk_tree_selection_select_iter(selection, &iter);
+    }
+
+
     /* set the window title */
     
     gtk_window_set_title(GTK_WINDOW(object), "NVIDIA X Server Settings");
     
     gtk_widget_show_all(GTK_WIDGET(object));
 
+
+    /* Set the minimum width of the tree view window to be something
+     * reasonable.  To do that, check the size of a label widget
+     * with a reasonably long string and limit the tree view scroll
+     * window's initial width to not extent past this.
+     */
+
+    label = gtk_label_new("XXXXXX Server Display ConfigurationXXXX");
+    gtk_widget_size_request(label, &req);
+    width = req.width;
+    gtk_widget_destroy(label);
+
+    /* Get the width of the tree view scroll window */
+    gtk_widget_size_request(sw, &req);
+
+    /* If the scroll window is too wide, make it slimmer and
+     * allow users to scroll horizontally (also allow resizing).
+     */
+    if ( width < req.width ) {
+        gtk_widget_set_size_request(sw, width, -1);
+        gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
+                                       GTK_POLICY_AUTOMATIC,
+                                       GTK_POLICY_AUTOMATIC);
+    }
+
     return GTK_WIDGET(object);
 
 } /* ctk_window_new() */
@@ -1103,7 +1147,7 @@ static void quit_response(GtkWidget *button, gint response, gpointer user_data)
  * saved to the config file.
  */
 
-static void add_special_config_file_attributes(CtkWindow *ctk_window)
+void add_special_config_file_attributes(CtkWindow *ctk_window)
 {
     GtkTreeModel *model = GTK_TREE_MODEL(ctk_window->tree_store);
     GtkTreeIter   iter;
@@ -1276,16 +1320,15 @@ static void update_display_devices(GtkObject *object, gpointer arg1,
             gtk_tree_selection_select_iter(tree_selection, &parent_iter);
         }
 
-        /* unref the page so we don't leak memory */
+        /* Remove the entry */
         gtk_tree_model_get(GTK_TREE_MODEL(ctk_window->tree_store), iter,
                            CTK_WINDOW_WIDGET_COLUMN, &widget, -1);
-        g_object_unref(widget);
-
-        /* XXX Call a widget-specific cleanup function? */
-
-        /* Remove the entry */
+       
         gtk_tree_store_remove(ctk_window->tree_store, iter);
 
+        /* unref the page so we don't leak memory */
+        g_object_unref(GTK_OBJECT(widget)); 
+
         data->num_displays--;
     }
     
