@@ -92,9 +92,18 @@ typedef void NvCtrlAttributeHandle;
 #define NV_CTRL_ATTR_EXT_LAST_ATTRIBUTE \
        (NV_CTRL_ATTR_EXT_XV_BLITTER_PRESENT)
 
-#define NV_CTRL_ATTR_XV_BASE \
+#define NV_CTRL_ATTR_NV_BASE \
        (NV_CTRL_ATTR_EXT_LAST_ATTRIBUTE + 1)
 
+#define NV_CTRL_ATTR_NV_MAJOR_VERSION           (NV_CTRL_ATTR_NV_BASE + 0)
+#define NV_CTRL_ATTR_NV_MINOR_VERSION           (NV_CTRL_ATTR_NV_BASE + 1)
+
+#define NV_CTRL_ATTR_NV_LAST_ATTRIBUTE \
+       (NV_CTRL_ATTR_NV_MINOR_VERSION)
+
+#define NV_CTRL_ATTR_XV_BASE \
+       (NV_CTRL_ATTR_NV_LAST_ATTRIBUTE + 1)
+
 #define NV_CTRL_ATTR_XV_OVERLAY_SATURATION      (NV_CTRL_ATTR_XV_BASE + 0)
 #define NV_CTRL_ATTR_XV_OVERLAY_CONTRAST        (NV_CTRL_ATTR_XV_BASE + 1)
 #define NV_CTRL_ATTR_XV_OVERLAY_BRIGHTNESS      (NV_CTRL_ATTR_XV_BASE + 2)
@@ -103,9 +112,11 @@ typedef void NvCtrlAttributeHandle;
 #define NV_CTRL_ATTR_XV_TEXTURE_SYNC_TO_VBLANK  (NV_CTRL_ATTR_XV_BASE + 5)
 #define NV_CTRL_ATTR_XV_TEXTURE_CONTRAST        (NV_CTRL_ATTR_XV_BASE + 6)
 #define NV_CTRL_ATTR_XV_TEXTURE_BRIGHTNESS      (NV_CTRL_ATTR_XV_BASE + 7)
-#define NV_CTRL_ATTR_XV_TEXTURE_SET_DEFAULTS    (NV_CTRL_ATTR_XV_BASE + 8)
-#define NV_CTRL_ATTR_XV_BLITTER_SYNC_TO_VBLANK  (NV_CTRL_ATTR_XV_BASE + 9)
-#define NV_CTRL_ATTR_XV_BLITTER_SET_DEFAULTS    (NV_CTRL_ATTR_XV_BASE + 10)
+#define NV_CTRL_ATTR_XV_TEXTURE_SATURATION      (NV_CTRL_ATTR_XV_BASE + 8)
+#define NV_CTRL_ATTR_XV_TEXTURE_HUE             (NV_CTRL_ATTR_XV_BASE + 9)
+#define NV_CTRL_ATTR_XV_TEXTURE_SET_DEFAULTS    (NV_CTRL_ATTR_XV_BASE + 10)
+#define NV_CTRL_ATTR_XV_BLITTER_SYNC_TO_VBLANK  (NV_CTRL_ATTR_XV_BASE + 11)
+#define NV_CTRL_ATTR_XV_BLITTER_SET_DEFAULTS    (NV_CTRL_ATTR_XV_BASE + 12)
 
 
 #define NV_CTRL_ATTR_XV_LAST_ATTRIBUTE \
@@ -197,6 +208,8 @@ typedef struct GLXFBConfigAttrRec {
     int multi_sample_valid;
     int multi_samples;
     int multi_sample_buffers;
+    int multi_sample_coverage_valid;
+    int multi_samples_color;
     
 } GLXFBConfigAttr;
 
